import * as React from 'react';
import { BaseModalProps, BaseModalProps2 } from './interface';
/**
 * 说明 BaseModal 是一个没有任何功能的组件，并不是一个Model。
 *
 * 但它有一些好处，特别适用于开发 Model的时候进行继承以达到简化代码的目的：
 *
 * 1.  `BaseModal` 约束了 `props` 参数，必须传入 `show:boolean`
 * 2. 可选参数可传入 `isEdit:boolean` `data:any` `dispatch:any` ，用于一般的弹框参数约束
 * 3. 可以传入任何扩展参数，自行设定（不会报TypeScript编译问题）
 * 4. 提供 `_isReShow(old)` 方法，判断每次触发 `render` 时，是不是重新打开
*/
export declare class BaseModal extends React.PureComponent<BaseModalProps, any> {
    _isReShow(old: any): boolean;
    _isShutDown(old: any): boolean;
}
/**
 * 说明：原 BaseModal 不再使用，使用 BaseModal2
*/
export declare class BaseModal2 extends React.PureComponent<BaseModalProps2, any> {
    _isReShow(old: any): boolean;
    _isShutDown(old: any): boolean;
}
