import { TableProps } from 'antd/lib/table/interface';
import { SelectBarOpts, SearchBarOpts, VTableColumn, KeyWord } from '../Table/interface';
/**
 * -----------------------------------------------------
 * --------------------STable-----------------------
 * VTable 的静态版本
 * --------------------------------------------------------
 * */
/**
 * VTable 的 Props 继承于 antd 的 Table 的 Props
 * 对原先的Table组件进行了一致性的调整和简化。易于统一的规范化使用
 * 说明：默认rowKey 为 `id`
*/
export interface STablePOpts extends TableProps<any> {
    /**
     * VTable 模式设置
     * common 默认： 普通模式
     * inner : 内置模式，放在布局组件里面显示时使用，使用此模式时，
     * fixed : 稳固模式，整个页面仅有VTable一个可见元素 时使用
     *
     */
    mode?: 'common' | 'inner' | 'fixed';
    /**
     * 在 fixed 模式下，除去固定的宽度
     */
    fixedHeight?: number;
    /**
     * 是否使用 table-layout: fixed,默认不使用
    */
    fixedCol?: boolean;
    /**
    * 模糊匹配
    */
    keyword?: KeyWord;
    /**
     * 左侧选择Panel
     * 树选择Panel，支持动态树和静态树，包含 loadData 参数的为动态树
    */
    selectBar?: SelectBarOpts;
    /**
     * 查询条件Panel
    */
    searchBar?: SearchBarOpts;
    /**
     * 序号字段
     * 1. 不传（或者传false） ：不显示 “序号”
     * 2. 传 true 显示 “序号”
     * 3. 传指定标题 ：显示指定标题
     *
     */
    showIndex?: boolean | string;
    /**
     * 列定义，参考 antd table columns ，扩展 show 属性
    */
    columns: VTableColumn[];
    /**
     * 静态Table 必须传 dataSource
    */
    dataSource: any[];
    /**
     * 是否可以多选，如果为 true，则出现多选框功能
    */
    select?: boolean;
    /**
     * 禁止选中的条件return true 禁止选中
     */
    selectDisabled?: (recode: any) => boolean;
    /**
     * 事件 : 相当于 rowSelection.onChange
     * 由于VTable 不支持原生 rowSelection
     * 所以需要监听选项变化时，传入 onSelectedChange = {(selectedRowKeys,selectedRows)=>xxx}
    */
    onSelectedChange?: (selectedRowKeys: string[] | number[], selectedRows?: any[]) => void;
    /**
     * 默认查询条件
    */
    default?: any;
    /**
     * 默认选中的 Key
    */
    defaultSelectedKeys?: (string | number)[];
}
