import * as React from 'react';
import { ColumnProps } from 'antd/lib/table/interface';
import { ButtonType } from 'antd/lib/button';
export type KeyWord = true | {
    /**
     * 高级搜索打开方式，默认为 click
     * 说明：暂不开放
    */
    /**
     * 弹出层宽度：默认为720
     * 说明：暂不开放
     *
     *
    */
    /**
     * 提示，默认为 "请填写关键字"
    */
    placeholder?: string;
    /**
     * 需要高亮的字段
     * 高亮设定： 说明：高亮设定后， column 指定的 render 会失效
    */
    highlight?: string[];
};
export type TableSelectBarProps = {
    /**
     * 选中一个项目后的回调方法
    */
    onSelect: (ids: string, obj: any) => any;
    /**
     * 搜索值
    */
    searchValue?: string;
    /**
     * 自定义扩展配置
    */
    config?: any;
};
/**
 * 通用 Table 左侧组件定义
*/
export type TableSelectBar = React.ClassType<TableSelectBarProps, any, any>;
export type TableSelectFieldProps = {
    width?: string | number;
    /**
     * field
    */
    field: Field;
    /**
     * 选中一个项目后的回调方法
    */
    onChange: (value: any) => void;
    /**
     * 触发搜索
    */
    triggerSearch: () => void;
    /**
     * 数据
    */
    data: any;
};
/**
 * 通用 Table 搜索字段定义
*/
export type TableSelectField = React.ClassType<TableSelectFieldProps, any, any>;
/**
 * 通用 Table 左侧容器定义
*/
export interface SelectBarOpts {
    /**
     * 标题:只能是文字
     * 1. 当类型为 tree，且启动搜索时，标题为一个输入框里面的 placeHolder
     */
    title: string;
    /**
     * @deprecated
     * 右上角的操作区域
     * 暂不会删除，为保证各样式统一，优先使用 btns 定义操作按钮
    */
    actions?: React.ReactNode;
    /**
     * 右上角的操作区域，只显示一个图标
    */
    btns?: {
        /**
         * 图标 type
        */
        icon: string;
        /**
         * html title 悬浮提示
        */
        title?: string;
        /**
         * 点击图回调
        */
        onClick: () => void;
        /**
         * 按钮文字
        */
        text?: string;
        /**
         * onClick前的提示
        */
        confirm?: string;
        /**
         * 是否展示 ，默认为true, 用于某些逻辑
        */
        show?: boolean;
        /**
         * 权限编码
        */
        roleCode?: string;
    }[];
    /**
     * type ： 左边树的类型
     * 说明：和 UForm类似, 除目前内置类型外，支持自定义扩展
     * 目前内置的类型有 ： stree  , ftree ,   dtree,
     * 微服务版在统一部分额外扩展了 :  organizion , domain , bar , list 等。
     * 不满足的，可根据实际需要在业务模块内自行扩展
     * 建议内部扩展的 type 以  "模块名-" 开头，避免类型冲突
     */
    type: 'stree' | 'ftree' | 'dtree' | string;
    /**
     * 宽度，默认为250
     */
    width?: number;
    /**
     * 自定义样式
     */
    style?: React.CSSProperties;
    /**
     * 选中中后事件
     * 1：如果是 VTable 里面使用，可以返回一个搜索对象
     * 2: 如果是自定义，请不要返回
     */
    onSelect: (key: string | number | any, object?: any, parent?: any) => any;
    /**
     * 原生antd 扩展属性,根据不同的输入参数，会在最终生成的组件上传入指定的Config
     * 比如文本类型时，
     * {type:'text', config :{size:'small'}} 时 会输出 为 <Input  size="small" />
     * 具体原生属性怀情查阅antd文档
     *  */
    config?: any;
    /**
     * 是否可以过滤
    */
    filter?: boolean;
}
/**
 * 搜索条件字段
*/
export interface Field {
    /**
     * api通信对应条件的字段
     */
    field: string;
    /**
     * 字段标签
     */
    label: string;
    /**
     * 默认为1，最多为3，超过3按3算，小于1 按1算，
     * 可以参考 antd Descriptions / DescriptionItem 里面文档里面的 span 的用法
     *  */
    span?: number;
    /**
     * 字段类型，目前支持
     * text                文本输入（默认）
     * number               文本输入（数字）
     * autocomplete          文本输入（自动完成）
     * select               普通选择器
     * multiselect          多项选择器
     * dictselect           字典选择器（必须指定字典ID）
     * treeselect           静态树选择器（暂不支持动态树）
     * inputselect          输入框，但有辅助选项
     * radio                单选框（强㓡使用外置Label）
     * checkbox             复选框（强制使用外围Label）
     * datetime             时间（如 2010-06-25 12:00:00）
     * date                 日期 (如 2010-06-25)
     * month                月份 (如 2010-06-01) 返回选择月份的首日
     * timerange            时间区间
     * daterange            日期区间
     *
     *
     * 支持中：
     * radiomore            单选，可自定义更多
     * switch               双状态切换
     * sider                区间划动
    */
    type?: string;
    /**
     * 是否展示
     */
    show?: boolean;
    /**
     * 输入框里面的提示
     */
    placeholder?: string;
    /**
     * 是否可以清除 支持 text
     *   */
    allowClear?: boolean;
    /**
     * 带图标的文本框，说明：部分输入类型支持
     */
    icon?: string;
    /**
     * select / multiselect / radio / checkbox 时，需要带的选项
     * 使用方法1: 传入一个数组 ，以 {name:string,value:string|number} 的结构传入
     * 使用方法2: 传入一个对象， 以 data: any[] 传入选项数据，再指定 name : stirng, value ： string 来指定需要显示在页面的名称和选中后的取值
     */
    options?: {
        name: React.ReactNode;
        value: string | number;
    }[] | {
        data: any[];
        nameField: string;
        valueField: string;
    };
    /**
     * 扩展属性,具体使用方法后续说明
     *  */
    config?: any;
}
/**
 * VTable Button 区域点击后的方法，支持三个参数
 * @param ids 如果当前有选条目，则为选中条目的ID列表
 * @param objs 如果当前有选条目，则为选中条目的对象信息
 * @param param 当前表格的查询参数
*/
export type BTN_CLICK = (ids?: string[], objs?: any[], param?: any) => void;
/**
 * 默认事件
*/
export interface ActBTN {
    /**
 * 按钮文本
 */
    label?: string;
    /**
     * 按钮ICON
     */
    icon?: string;
    /**
     * 按钮样式，参考 Antd Button
     */
    type?: ButtonType;
    /**
     * 权限码，设置权限码后，仅当前用户有权限才会显示
    */
    roleCode?: string;
    /**
     * 至少选中一条才激活按钮，默认为false
     * 需要与 VTable 里面的 select 结合使用
     */
    mustSelect?: boolean;
    /**
     * 原生antd 扩展属性,
     * 比如
     * {type:'primary', config :{size:'small',shape:'circle'}} 时 会输出 为 <Button type="primary" size="small" shape="circle" />
     *
     *  */
    config?: any;
    /**
     * 操作提示
     */
    confirm?: string | ((ids?: string[], objs?: any[], param?: any) => React.ReactNode);
}
/**
 * 按钮定义
*/
export interface ActButton extends ActBTN {
    /**
     * 按钮文本
     */
    label: string;
    /**
     * 至少选中一条才激活按钮，默认为false
     * 需要与 VTable 里面的 select 结合使用
     */
    mustSelect?: boolean;
    /**
     * 过期，不允许再使用，统一改为 弹出上传框的交互模式 。
     * @deprecated
     * 上传地址（设置后，此按钮将变成上传按钮，暂不支持），
     * 1. 默认为 false: 不上传
     * 2. 传 true 时，上传到通用上传接口
     * 3. 传字符串时，传到指定的接口
     *
     * 2022-04-18 : 如果再传此属性，不显示，相当于 show : false ，并给出页面警告
     * 2022-05 ： 删除此属性，再传则会导致编译不通过
     */
    upload?: boolean | string;
    /**
     * 点击事件
     * */
    onClick: BTN_CLICK;
    /**
     * 说明，当传Children 时，以按钮变变为下拉按钮
     *
     * 1. 下拉按钮的 Icon 无效
     * 2. 下拉按钮的 onClick 可以传 null 也可以自定义方法
     * 3. 下拉按钮的 mustSelect,confirm，upload 无效
     * 4. 子按钮的暂时不能为 upload 类型
     * 5. 子按钮暂时不支持 confirm,但支持 mustSelect （后续支持）
     *
    */
    children?: ActButton[];
}
export interface SearchBarOpts {
    /**
     * searchBar扩展类名称
     */
    className?: string;
    /**
     * Label 是否在标签外面，默认为 false
     * 说明：某些组件不支持：
     * checkbox,radio,等
     * 如果包含了这些组件，会强制转换为 true
     */
    fieldOutside?: boolean;
    /**
     * 1. 默认为250
     * 2. 可以传1个数字 ，也可以传2个数字组成的一个数组
     * 3. 当传一个数字时，代表每个Field的总体宽度，如果是 outSide 模式，则Label宽度为80（容纳5个汉字）
     * 4. 如果想手动指定label宽度，则传入两个数字的数组，分别 为 [总宽度, label宽度]
     */
    fieldWidth?: number | [number, number];
    /**
     * 默认参数
     */
    default?: any;
    /**
     * 搜索参数
     */
    fields?: Field[];
    /**
     * 搜索参数支持的列，最多支持4，默认为3
     */
    cols?: 1 | 2 | 3 | 4;
    /**
     * 操作按钮列表
     *
     * */
    buttons?: (ActButton | null)[];
    /***
     * 是否以 Modal 方式弹出更多参数，默认为 false
     * false : 以展开方式显示更参数
     * true  : 以弹框方式显示死多参数
     *
     * 使用对象传递时：
     *
     * width: 宽度：默认 960
     * title: 标题：默认 “高级搜索”
    */
    useModal?: boolean | {
        width?: number;
        title?: React.ReactNode;
    };
}
export interface InnerSearchBarOpts extends SearchBarOpts {
    /**
     * 变量有变动时使用
    */
    onChange?: (param: any) => void;
    /**
     * 触发搜索时调用
     */
    onSearch?: (param: any) => void;
    /**
     * 选中的列ID
     */
    selectedRowKeys?: string[];
    /**
     * 选中的对象
     */
    selectObjects?: any[];
    /**
     * 展开回调，仅在表格里面使用
     */
    onExpands?: () => void;
    /**
     * 数据表请求参数
     */
    param?: any;
}
export interface InnerKeywordOpts extends InnerSearchBarOpts {
    keyword: KeyWord;
}
export interface VTableColumn extends ColumnProps<any> {
    /**
     * 是否展示 ，默认 true
    */
    show?: boolean;
    /**
     * 权限码，设置权限码后，仅当前用户有权限才会展示此列
    */
    roleCode?: string;
}
/**
 * 表格通用操作，目前支持查看，编辑，删除
*/
export interface ActionPorps {
    /**
     * 对象名称（）
    */
    name?: string;
    /**
     * 标题文字，默认
    */
    title?: string;
    /**
     * 点击方法
    */
    onClick: () => void;
    /**
     * 权限码,如果定义此项，将只在具
    */
    roleCode?: string;
}
/**
 * 自定义操作
*/
export interface CustomAciton extends ActionPorps {
    /**
     * 在自定义操作中，title 为必填项
    */
    title: string;
    /**
     * 图标ICON，
    */
    icon?: string;
    /**
     * 自定义操作的样式，可以为 'INFO' | 'EDIT' | 'DELETE'
     * 仅改变操作的颜色，如果是DELETE 样式，建议再传入 confrim
    */
    type?: 'INFO' | 'EDIT' | 'DELETE';
    /**
     * 自定义操作的二次确认提示
    */
    confrim?: React.ReactNode;
}
