export type TreeNodeData = {
    children?: TreeNodeData[];
    [props: string]: any;
};
import type { ReactNode } from 'react';
import { UFormField } from '../UForm/interface';
/**
 * 基础参数
*/
export type BaseTreeOpts = {
    className?: string;
    style?: React.CSSProperties;
    /** 是否禁用树 */
    disabled?: boolean;
    /** 默认展开所有树节点 */
    /**
     * 树取值的字段，默认为 `id`
    */
    keyField?: string;
    /**
     * 树显示名称的字段 ，默认为 `name`
    */
    titleField?: string;
    /**
     * 树显示Icon字段 ，默认为空，传入后，以此字段显示图标
    */
    iconField?: string | ((item: any) => ReactNode);
    /**
     * 排序字段,默认为空，传入后，以此字段做为排序依据
    */
    sortField?: string;
    /**
    * 父节点
    */
    parentField?: string;
    /**
     * 是否默认展开所有结点
    */
    defaultExpandAll?: boolean;
    /**
     * 默认展开指定的树节点
     */
    defaultExpandedKeys?: string[];
    /**
     * 是否必选，
    */
    mustSelect?: boolean;
    /**
     * 选中后的回调函数
     * 参数1 ： key
     * 参数2 ： 选中的对象，可能会返回空
     * 参数3 :  选中对象的父节点
     * 参数4 :  选中对象的位置
    */
    onSelect?: (key: any, object?: any, parent?: any, pos?: any) => void;
    /**
     * 搜索关键字
    */
    searchValue?: string;
    /**
    * 根节点 Code 标识
    */
    rootCode?: string;
    /**
     * add,edit
    */
    formFields?: UFormField[];
};
export type STreeOpts = BaseTreeOpts & {
    /**
     * 树数据
     *  */
    treeData: TreeNodeData[];
    /**
     * 是否扁平数据,默认非扁平数据
    */
    isFlat?: boolean;
};
export type TreeAction = {
    /**
     * 对象的 Label
    */
    objectName?: string;
    /**
     * 添加、修改、删除的接口
     * 需要符合VAP规范
     * 必须传些参数才有 CRUD功能
    */
    api?: string;
    /**
     * 是否可以插入节点
    */
    canAdd?: boolean;
    /**
     * 根节点处
    */
    canAddRoot?: boolean;
    /**
     * 是否可以修改节点
    */
    canUpdate?: boolean;
    /**
     * 是否可以删除节点
    */
    canDelete?: boolean;
    /**
     * 是否支持排序
    */
    canSort?: boolean;
    /**
     * 添加编辑，使用UForm,如果不传，则自动使用 key,title,parent,icon,
    */
    /**
     * 是否去缓存，默认缓存，如果强制不缓存，则传 notCache = true
    */
    notCache?: boolean;
    /**
     * add,edit
    */
    formFields?: UFormField[];
};
export type DTreeOpts = BaseTreeOpts & TreeAction & {
    /**
     * 根节点API 与rootCode 二选一
    */
    rootApi?: string;
    /**
     * 直接传根节点数据，暂不支持
    */
    /**
     * 是否存在子节点，如果有些属性，则根据此值不必多点一次加号
    */
    checkField?: string;
    /**
     * 展开子节点：
     *
     * 方式一：传一个 api 接口地址，必须返回 VData<Array<Object>> 格式
     *
     * 方式二：传一个方法 ，接收一个父节点参数，必须返回  Promise<TreeNodeData[]> (不要返回 children, 仅返回一级)
    */
    childApi: string | ((parentId: string) => Promise<TreeNodeData[]>);
    /**
     * 默认选中
     */
    defaultValue?: any;
};
export type FTreeOpts = BaseTreeOpts & TreeAction & {
    /**
     * 获取全部节点的API，如果不传，刚用 API 的GET模式代替
    */
    fetchApi?: string;
};
