import { ModalProps } from 'antd/lib/modal/Modal';
import * as React from 'react';
/**
 * 导入结果
 * 返回 boolean ： true / false ,成功 / 失败
 * 如果需要显示提示信息，则返回结构体 ，例如
 * return {ok:true, message:'成功导入111条记录'}
*/
export type ImportResult = boolean | {
    message: React.ReactNode;
    ok: boolean;
};
/**
 * 通用上传弹框
 *
 * 1. 约束：表格右上角的按钮，不再直接上传，统一改为 “导入”
   2. 点击导入后，弹出文件上传弹框
   3. 标题要体现导入的信息
   4. 提示要说明需要上传的数据描述，也可以提供模板下载
   5. 上传按钮仅支持单选，需要指定上传格式
   6. 选择文件后立即开始上传。
   7. 上传完成后显示上传结果，成功 OR 失败，失败时重新上传
   8. 成功后直接进行导入
   9. 导入成功后显示结果，成功 OR 失败，失败时重新上传
   0. 成功后可关闭窗体，关闭后可自行刷新数据。
*/
export interface UploadModalProps extends ModalProps {
    /**
     * 上传接口，上传接口地址，默认是标准接口，即 '/api-common/file/upload'
    */
    api?: string;
    /**
     * 接受上传文件类型， http://www.iana.org/assignments/media-types/media-types.xhtml
     *
     * 常用参考
     * 	accept="application/zip"
     *  accept="application/x-zip-compressed"
     *  accept="application/vnd.ms-excel,applicat ion/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
     *  accept=".json"
     *  accept=".csv"
     *  accept=".pdf,.zip"
     *  accept="audio/*"
     *  accept="video/*"
     *  accept="image/*"
     *
     *
     * 说明，默认为 "application/vnd.ms-excel,application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
    */
    accept?: string;
    /**
     * 上传文件的字段名称，默认为 "file"
    */
    name?: string;
    /**
     * 上传提示，通常包括上传数据说明，数据模板文件下载等内容。
     * 默认 ： 请注意：导入的Excel数据字段须与Excel模版保持一致，否则无法导入数据。点击确认时将仅导入正常数据。
    */
    tip?: React.ReactNode;
    /**
     * 附带上传的的数据,默认 : {namespace:'app-portal'}
    */
    data?: any;
    /**
     * 二步模式，且上传接口非标准接口时，必传 onUpload
     * 返回上传结果 boolean  成功 OR 失败
    */
    onUpload?: (data: any) => ImportResult;
    /**
     * 上传
    */
    onResult: (result: any) => Promise<ImportResult> | ImportResult;
    /**
     * onCancel 强制为必传
    */
    onCancel: (e?: React.MouseEvent<HTMLElement>) => void;
}
