/// <reference types="react" />
import { FormComponentProps, ValidationRule } from 'antd/lib/form/Form';
import { ModalProps } from 'antd/lib/modal/Modal';
import { SelectModalProps } from './_SelectModal';
import { EditTableProps } from './_EditTable';
import { EditTagProps } from './_EditTag';
import { ButtonType } from 'antd/lib/button';
export interface Column {
    /**
     * 列名称，传null或false时表示无标题
    */
    title: string | React.ReactNode;
    /**
     * 列字段
    */
    field: string;
    /**
     * 输入提示
    */
    placeholder?: string | false;
    /**
     * 是否显示，默认显示true，不显示可以设置为showed:false
    */
    show?: boolean;
    /**
     * 是否禁用，默认不禁用，禁用可以设置为 disabled:true
    */
    disabled?: boolean;
    /**
     * 仅用于展示时转义，原始值存储到state里面，提交时会替换
     */
    render?: Function;
    /**
     * 字段类型 目前支持类型如下，默认text
     * 'text' | 'number' | 'month' | 'select' | 'radio' | 'checkbox' | 'date' | 'time' | 'switch' | 'daterange' | 'icon' | 'cascader' | 'textarea' | 'file'|'fileinfo' | 'transfile' | 'password' | 'image' | 'modal' | 'selectmodal' | 'vformmodal' | 'edittable' | 'tag'|'dateNull';
     */
    type?: string;
    /**
     * 该项目占的行数，覆盖外层的span
     */
    span?: number;
    /**
     * 在表单项后面仅跟着一个输入框，作为该输入值的扩展
     */
    tail?: string | VTail;
    /**
     * 字段选项，适用于 `checkbox` `radio` `switch` 等
     * 当字段类型为 `switch`时， 数组长度必须为 2, 第一个参数放正常状态，第二个参数放异常状态
    */
    options?: {
        name?: string;
        value?: string | number;
        children?: object[];
        [propName: string]: any;
    }[];
    /**
     * 子组件配置项，如modal, selectmodal, vformmodal, edittable, tag等子组件出现时，对非标准表单元素添加属性
     */
    subConfig?: SubConfig;
    /**
     * 上传的图标组件, 默认<Button icon='upload'>上传</Button>
     * 传入string时，表示修改button的文字
     */
    uploadButton?: React.ReactNode | 'string';
    /**
     * 表单名称的提示信息
     */
    tip?: string | {
        text: string;
        icon: string;
    };
    /**
     * rule 用法： https://github.com/yiminghe/async-validator
    */
    rule?: ValidationRule[] | any[];
    /**
     * 字段联动，目前支持其他字段是否展示、是否禁用、以及值改变
    */
    link?: {
        unshow?: (value: any, init?: any) => string[];
        disabled?: (value: any, init?: any) => string[];
        valuesChange?: (value: any, init?: any) => object;
        optionsChange?: (value: any, init?: any) => {
            [fieldName: string]: {
                name?: string;
                value?: string | number;
                children?: object[];
            }[];
        };
    };
    /**
        * column名称宽度，默认为120px
        */
    labelWidth?: number;
    /**
     *  扩展字段说明：
     * 1. 当 type 为 organization 时，config 为  {businessLine?: string, useRoot?: boolean,} 业务线：默认为全部，使用root 默认为false
     * 2. 当 type 为 autocomplete 时, config 为  {fetch:stirng,'queryapi',field:string='name', name?:string = 'name',value:stringg = 'id'}
     */
    config?: any;
    /**
     * 是否支持增减表单项
     */
    addItem?: boolean;
    /**
     * upload 下载模板配置
     */
    templateDownload?: string | {
        url: string;
        text?: string;
        icon?: string;
    };
}
interface SubConfig {
    /**
     * selectModal的props，可额外传入弹窗相关属性
     */
    selectModalProps?: SelectModalProps;
    /**
     * edittable的props，可额外出入Table的相关属性
     */
    editTableProps?: EditTableProps;
    /**
     * edittag的props
     */
    tagProps?: EditTagProps;
    /**
     * 其他
     */
    [propsName: string]: any;
}
interface VTail {
    /**
     * tail存储时的分隔符，默认为 //
     */
    separator?: string;
    /**
     * tail的字段名，无字段名会通过separator挂载到主字段上
     */
    field?: string;
    /**
     * tail输入时提示内容
     */
    placeholder?: string;
    /**
     * formitem，表示单独形成一个无label的FormItem
     * expand，表示在形成一个默认width的input
     * any[]，继承expand样式，表示只有当前column的取值被包含在该数组时，才会显示tail，类似于radiomore
     */
    type?: 'formitem' | 'expand' | any[];
    /**
     * 只有expand状态才生效
     */
    expandWidth?: number;
}
interface VFromCommon {
    /**
     * 表单的key
     */
    formKey?: string | number;
    /**
    * 表单的列定义，传一个数组
    */
    columns: Column[];
    /**
     * 表单传入的对象值
    */
    data?: any;
    /**
     * 对象组件的默认值
    */
    default?: any;
    /**
     * 表单布局，默认default，就是表单的horizontal布局
     * leftText：继承horizontal，但所有的label文字都左对齐
     * table：给表单项添加边界线，去掉marging和padding
     */
    layout?: 'default' | 'leftText' | 'table';
    /**
     * 表单名称宽度，默认为120px
     */
    labelWidth?: number;
    /**
     * 分列数，默认1列，当为对象时，key为分列数，value为该分列中的字段，多个字段用逗号隔开
     */
    span?: number | {
        [propName: number]: string;
    };
    /**
     * 列之间的间距，默认12
     */
    gutter?: number;
    /**
     * 标题样式加深
     */
    titleDeep?: boolean;
    /**
     * 分组
     * panels:分组的标题和属性集合，title为每个分组的标题，fields为每个分组包含的表单项，多个表单项用逗号隔开
     * other：不在panels里面的列默认归为这个组，为false不展示，为string展示该名称
     */
    group?: {
        panels: {
            title: string | React.ReactNode;
            fields: string;
        }[];
        other?: string | false;
    };
    /**
     * 点击确定回调
     */
    onOk?: (e: React.MouseEvent<HTMLElement>) => void;
    /**
     * 点击模态框右上角叉、取消按钮、Props.maskClosable 值为 true 时的遮罩层或键盘按下 Esc 时的回调
    */
    onCancel?: (e: React.MouseEvent<HTMLElement>) => void;
    /**
     * 当存在group时，控制Collaps的展开与折叠动作，一般不需要使用
     */
    isClose?: boolean;
    labelExpand?: any;
}
export interface VFormProps extends FormComponentProps, VFromCommon {
    /**
     * 底部按钮位置
     */
    footPosition?: 'right' | 'left' | 'bottom-left' | 'bottom-right';
    /**
     * 底部内容，构造footer后，onOk和onCancle就无效
     * 参数为待提交的表单参数，自定义参数时，无法自动校验
     */
    footer?: (v?: any) => React.ReactNode;
    /**
     * 确定按钮的文字，为false则不展示确定按钮
     */
    okText?: React.ReactNode;
    /**
     * 确认按钮类型
     */
    okType?: ButtonType;
    /**
     * 取消按钮类型
     */
    cancelType?: ButtonType;
    /**
     * 取消的弹窗，默认取消不带弹窗确认
     */
    cancelPopover?: boolean;
    /**
     * 取消按钮的文字，为false则不展示取消按钮
     */
    cancelText?: React.ReactNode;
    onValuesChange?: (allValues: any) => void;
}
export interface VFormModalProps extends ModalProps, VFromCommon {
    /**
     * 获取Form对象，可调用props.form的相关方法，和wrappedComponentRef作用一样
     */
    formRef?: (form: any) => void;
    tabs?: {
        title: string;
        key: string;
        fields: string;
    }[];
    /**
     * 是否在标题右侧显示全部关闭和展开字样，不显示则为null
     */
    foldIcon?: [React.ReactNode, React.ReactNode] | null;
}
export {};
