import { TableProps } from 'antd/lib/table/interface';
import { SelectBarOpts, SearchBarOpts, VTableColumn, KeyWord } from '../../_common/Table/interface';
/**
 * -----------------------------------------------------
 * --------------------VTable-----------------------
 * --------------------------------------------------------
 * */
/**
 * VTable 的 Props 继承于 antd 的 Table 的 Props
 * 对原先的Table组件进行了一致性的调整和简化。易于统一的规范化使用
 * 说明：默认rowKey 为 `id`
*/
export interface VTablePOpts extends TableProps<any> {
    /**
     * VTable 模式设置
     * common 默认： 普通模式
     * inner : 内置模式，放在布局组件里面显示时使用，使用此模式时，
     * fixed : 稳固模式，整个页面仅有VTable一个可见元素 时使用
     *
     */
    mode?: 'common' | 'inner' | 'fixed';
    /**
     * 说明：
     * 1. 建议规范：
     *      请以 app-{appName}-{tableName}-talbe 命名
     *      比如 app-portal-user-table
     * 2. 此功能入口将出现在序号后面，拟
     *      所以要想使用此功能，showIndex 不能传false (可以不传 / 或传字符串 / 或者传true)
     * 3. 内部实现是根据 showIndex 字段实现的
     *      如果想排序，请传 showIndex ,如果不想排序，则不传，比如 （操作），可以不传
    */
    columnCache?: string;
    /**
     * 在 fixed 模式下，除去固定的宽度
     */
    fixedHeight?: number;
    /**
     * 是否使用 table-layout: fixed,默认不使用
    */
    fixedCol?: boolean;
    /**
    * 模糊匹配
    */
    keyword?: KeyWord;
    /**
     * 左侧选择Panel
     * 树选择Panel，支持动态树和静态树，包含 loadData 参数的为动态树
    */
    selectBar?: SelectBarOpts;
    /**
     * 查询条件Panel
    */
    searchBar?: SearchBarOpts;
    /**
     * 序号字段
     * 1. 不传（或者传false） ：不显示 “序号”
     * 2. 传 true 显示 “序号”
     * 3. 传指定标题 ：显示指定标题
     *
     */
    showIndex?: boolean | string;
    /**
     * 列定义，参考 antd table columns ，扩展 show 属性
    */
    columns: VTableColumn[];
    /**
     * 是否自动 fetch ，默认为 true
     */
    autoLoad?: boolean;
    /**
     * dva的命名空间，
     * 说明， 如果是标准的 list-model 模型， 可以只传递一个 namespace 参数 即 模型在 dva 里面的命名空间
     * 非标准模型依然可以使用旧的方式分别 传入 fetch/total/dataSource
     */
    namespace?: string;
    /**
     * 发动 fetch 的事件字符串，由 {moduleName}/{moudleMethod} 组成
    */
    fetch?: string;
    /***
     * 搜索前转换查询参数
     */
    beforeSearch?: (param: any) => any;
    /**
     * 记录总数
    */
    total?: number;
    /**
     * 每页显示记录数，默认为10
    */
    /**
     * 是否可以多选，如果为 true，则出现多选框功能
    */
    select?: boolean;
    /**
     * 禁止选中的条件return true 禁止选中
     */
    selectDisabled?: (recode: any) => boolean;
    /**
     * 事件 : 相当于 rowSelection.onChange
     * 由于VTable 不支持原生 rowSelection
     * 所以需要监听选项变化时，传入 onSelectedChange = {(selectedRowKeys,selectedRows)=>xxx}
    */
    onSelectedChange?: (selectedRowKeys: string[] | number[], selectedRows?: any[]) => void;
    /**
     * 默认搜索参数
    */
    default?: any;
}
