/// <reference types="react" />
import { RowProps } from 'antd/lib/row';
export interface VRowProps extends RowProps {
    height: number | string;
}
/**
 * 面板
*/
export interface VPanelProps {
    /**
     * 面板标题前的 ICON
    */
    icon?: string;
    /**
     * 面板标题
    */
    title?: React.ReactNode;
    /**
     * 标题下标额外内容（以 small小一号）展示
    */
    titleSub?: React.ReactNode;
    /**
     * 标题样式
    */
    titleStyle?: React.CSSProperties;
    /**
     * 内容样式
    */
    contentStyle?: React.CSSProperties;
    /**
     * 皮肤样式，测试中
     * grid :  网格
     * borderless : 无边框
     * yellow : 黄
     * blue   : 蓝
     * pink   : 粉
     * green  : 绿
    */
    theme?: 'grid' | 'borderless' | 'yellow' | 'blue' | 'pink' | 'green';
    /**
     * 标题后面的帮助文案
    */
    help?: React.ReactNode;
    /**
     * 二级标题（详情描述）
    */
    titleDesc?: React.ReactNode;
    /**
     * @deprecated
     * 右上角的操作区域
     * 暂不会删除，为保证各样式统一，优先使用 btns 定义操作按钮
    */
    actions?: React.ReactNode;
    /**
     * 右上角的操作区域，只显示一个图标
    */
    btns?: {
        /**
         * 图标 type
        */
        icon: string;
        /**
         * html title 悬浮提示
        */
        title?: string;
        /**
         * 点击图回调
        */
        onClick: () => void;
        /**
         * 按钮文字
        */
        text?: string;
        /**
         * onClick前的提示
        */
        confirm?: string;
        /**
         * 是否展示 ，默认为true, 用于某些逻辑
        */
        show?: boolean;
        /**
         * 权限编码
        */
        roleCode?: string;
    }[];
    /**
     * 空数据判断
     * 传 true =  数据为空
     * 传 false = 数据不为空 (默认)
     * 传 数组时 = ((数组 == null) 或者 (数组长度 == 0 )) 为空
    */
    empty?: boolean | any[];
    /**
     * 数据为空时的文案，默认：“暂无数据”
     */
    emptyText?: string;
    /**
     * 是否正在 loading 状态，推荐使用 loading_effect
     */
    loading?: boolean;
    /**
     * 根据对应的 effect 自动判断是否正在 loading 状态，
     * 支持传一个或多个 effect
     */
    loading_effect?: string | string[];
    /**
     * 内容
    */
    children?: React.ReactNode;
}
/**
 * 排版 ： 一列
*/
export interface VColProps extends VPanelProps {
    /**
     * 附加样式名称
    */
    className?: string;
    /**
     * 是否去背景模式（使用多层排版时可当容器使用）
    */
    noBg?: boolean;
    /**
     * 自定义样式
    */
    style?: React.CSSProperties;
    /**
     * span
     * xs   < 576px
     * sm   ≥ 576px
     * md   ≥ 768px
     * l    ≥ 992px
     * xl   ≥ 1200px
     * xxl  ≥ 1600px
     * 参考 antd Col
    */
    span?: number;
    xs?: number;
    sm?: number;
    md?: number;
    lg?: number;
    xl?: number;
    xxl?: number;
}
/**
 * 封装的排版，与内容一起封装，
 * 适合展示特殊数据
 *
*/
export interface VGrid extends VColProps {
    /**
     * 背景颜色
    */
    bgStyle?: 'info' | 'success' | 'warn' | 'error' | 'primary' | 'default';
    /**
    * 背景颜色强度，每种颜色分3个等级
    */
    bgStrength?: 'weak' | 'normal' | 'strong';
    /**
     * 点击事件
    */
    onClick?: () => void;
}
export interface VGridNumber extends VGrid {
    /**
     * 如果有此属性，点击这个格子将会跳到对应的页面
    */
    linkTo?: string;
    /**
    * 数字
    */
    numberValue?: number;
    /**
     * 数字动画，仅在传 numberValue 时有效
    */
    numberAnimation?: boolean;
    /**
     * 数字格式，仅在传 numberValue 时有效
    */
    numberFormat?: 'default' | 'usd' | 'default' | 'number' | 'usd' | 'percent' | 'chinese' | 'decimal' | 'size' | ((number: any) => string);
    /**
     * 数字格子样式
     * fullBg: 仅有背景色，无标题格式，且标题在上方，内容在下方
     */
    type?: 'default' | 'fullBg';
}
export interface VGridChart extends VGrid {
}
/**
 * 组装 VRow + VCol， 一种简写方式。 单行内容时可以直接成 <VRowCol> 不需要 <VRow><VCol></Vcol></VRow>
*/
export interface VRowColProps extends VPanelProps {
    className?: string;
    style?: React.CSSProperties;
    height: number | string;
    /**
     * VCol 的额外样式
    */
    colClassName?: string;
    /**
    * VCol 的额外样式
   */
    colStyle?: React.CSSProperties;
}
