"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.base65 = exports.base64 = void 0;
var base64EncodeChars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
var TIME_LEN = 16;
var base64 = function (str) {
    var out, i, len;
    var c1, c2, c3;
    len = str.length;
    i = 0;
    out = [];
    while (i < len) {
        c1 = str.charCodeAt(i++) & 0xff;
        if (i == len) {
            out.push(base64EncodeChars.charAt(c1 >> 2));
            out.push(base64EncodeChars.charAt((c1 & 0x3) << 4));
            out.push("==");
            break;
        }
        c2 = str.charCodeAt(i++);
        if (i == len) {
            out.push(base64EncodeChars.charAt(c1 >> 2));
            out.push(base64EncodeChars.charAt(((c1 & 0x3) << 4) | ((c2 & 0xF0) >> 4)));
            out.push(base64EncodeChars.charAt((c2 & 0xF) << 2));
            out.push("=");
            break;
        }
        c3 = str.charCodeAt(i++);
        out.push(base64EncodeChars.charAt(c1 >> 2));
        out.push(base64EncodeChars.charAt(((c1 & 0x3) << 4) | ((c2 & 0xF0) >> 4)));
        out.push(base64EncodeChars.charAt(((c2 & 0xF) << 2) | ((c3 & 0xC0) >> 6)));
        out.push(base64EncodeChars.charAt(c3 & 0x3F));
    }
    return out.join('');
};
exports.base64 = base64;
/**
 * 说明 ：
 * 1. Base65 为内部研发，支持时间验证与密码加盐，盐支持0-5的数字，默认为3，需要后端同步修改
 * 2. base65 加密没有太的安全性，主要用于某些扫描软件报错，如果强要求安全只能使用非对称RSA加密
 * 3. 需要后端复制一个解决函数进行解密
*/
var base65 = function (str, salt) {
    if (salt === void 0) { salt = 3; }
    salt = salt % 5;
    var password = (0, exports.base64)(str);
    var timeStr = (new Date().getTime() + '').substring(1, 12) + String.fromCharCode(65 + str.length);
    var time = (0, exports.base64)(timeStr);
    var buf = [];
    var mixlen = password.length < TIME_LEN ? password.length : TIME_LEN;
    for (var i = 0; i < mixlen; i++) {
        buf.push(String.fromCharCode(password.charCodeAt(i) - salt));
        buf.push(time.charAt(i));
    }
    if (mixlen < TIME_LEN) {
        buf.push(time.substring(mixlen));
    }
    else {
        for (var i = TIME_LEN; i < password.length; i++) {
            buf.push(String.fromCharCode(password.charCodeAt(i) - salt));
        }
    }
    var result = buf.join('');
    return result;
};
exports.base65 = base65;
