type PasswordCheckerOptions = {
    /**
     * 最小长度，默认：6
    */
    minLength?: number;
    /**
     * 最大长度，默认：32
    */
    maxLength?: number;
    /**
     * 必须包含数字
    */
    requireNumber?: boolean;
    /**
     * 必须包含大写字母
    */
    requireUpperLetter?: boolean;
    /**
     * 必须包含小写字母
    */
    rqueireSymbol?: boolean;
};
/**
 * 密码复杂度,安全等级判断
*/
export declare class PasswordChecker {
    constructor(options?: PasswordCheckerOptions);
    check(txt: string): boolean;
    /**
     * 说明
     * 一. 密码长度
     *  1) 5 分: 小于等于 4 个字符
     *  2) 10 分: 5 到 7 字符
     *  3) 25 分: 大于等于 8 个字符
     * 二. 字母
     *  1) 0 分: 没有字母
     *  2) 10 分: 全都是小（大）写字母
     *  1) 2 分: 字母和数字
     *  2) 3 分: 字母、数字和符号
     *  3) 5 分: 大小写字母、数字和符号
    */
    strong(txt: string): number;
    /**
     * 0: 非常弱
     * 25: 弱（Weak）
     * 50: 一般（Average）
     * 60: 强（Strong）
     * 70: 非常强
     * 80: 安全（Secure）
     * 90: 非常安全
     *
     * 说明，返回 false , 说明密码没有通过验证
    */
    safeCheck(txt: string): string | false;
}
export {};
