"use strict";
/**
 * 吉大正元 PKI 证书登录, 已经内置所有已知的KEY，
 *
 * 大致使用方式 如下
 * import { JitClient } from 'vap2/login/jit'
 * const client = JitClient();                                  // 接收 1-3个参数，用于不同版本的控制
 * const randomNumber = await Ajax.GET('/api/randomNumber');    // 后端 生成一个随机数
 * const param = client.getLoginParam(randomNumber);            // 插件 获取登录参数
 * const loginResult = await Ajax.GET('/api/pkilogin');         // 后端 登录接口
 *
 * 如果 key 未知时，getLoginParam 需要传新的KEY
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.JitClient = exports.BROWSER_MODE = void 0;
var BROWSER_MODE;
(function (BROWSER_MODE) {
    BROWSER_MODE[BROWSER_MODE["IE"] = 0] = "IE";
    BROWSER_MODE[BROWSER_MODE["CHROME"] = 1] = "CHROME";
    BROWSER_MODE[BROWSER_MODE["CHROME_OLD"] = 2] = "CHROME_OLD";
})(BROWSER_MODE = exports.BROWSER_MODE || (exports.BROWSER_MODE = {}));
var pnxclient_1 = require("./pnxclient");
var JitClient = /** @class */ (function () {
    /**
     * @param initParam         插件初始化参数，是一个XML字符串，在不同的项目，参数会不同，可以配置在后端返回
     * @param enablectiveX      是否支持 旧版本 IE ActiveX 登录 , 默认支持
     * @param enableNPPlugin    是否支持 旧版本 Chrome NppPlugin 登录 ， 默认支持，部分地区不支持
    */
    function JitClient(initParam, enablectiveX, enableNPPlugin) {
        if (enablectiveX === void 0) { enablectiveX = true; }
        if (enableNPPlugin === void 0) { enableNPPlugin = true; }
        // 内置所有已知的吉大KEY
        this.initParam = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<authinfo>\n    <liblist>\n        <lib type=\"SKF\" version=\"1.1\" dllname=\"U2h1dHRsZUNzcDExXzMwMDBHTS5kbGw=\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SM3\" />\n        </lib>\n        <lib type=\"CSP\" version=\"1.0\" dllname=\"RkVJVElBTiBlUGFzc05HIENTUCBGb3IgSklUM0sgVjEuMA==\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SHA1\" />\n        </lib>\n        <lib type=\"SKF\" version=\"1.0\" dllname=\"RW50ZXJTYWZlIGVQYXNzMzAwMyBDU1AgdjEuMA==\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SM3\" />\n        </lib>\n        <lib type=\"PM\" version=\"1.0\" dllname=\"Q3J5cHRPY3guZGxs\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SM3\" />\n        </lib>\n        <lib type=\"CSP\" version=\"1.0\" dllname=\"RUlUSUFOIGVQYXNzTkcgUlNBIENyeXB0b2dyYXBoaWMgU2VydmljZSBQcm92aWRlcg==\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SHA1\" />\n        </lib>\n        <lib type=\"CSP\" version=\"1.0\" dllname=\"SklUIFVTQiBLZXkgQ1NQIHYxLjA=\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SHA1\" />\n        </lib>\n        <lib type=\"CSP\" version=\"1.0\" dllname=\"RW50ZXJTYWZlIGVQYXNzMjAwMSBDU1AgdjEuMA==\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SHA1\" />\n        </lib>\n        <lib type=\"CSP\" version=\"1.0\" dllname=\"SklUIFVTQiBLZXkzMDAzIENTUCB2MS4w\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SHA1\" />\n        </lib>\n        <lib type=\"CSP\" version=\"1.0\" dllname=\"RkVJVElBTiBlUGFzc05HIFJTQSBDcnlwdG9ncmFwaGljIFNlcnZpY2UgUHJvdmlkZXI=\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SHA1\" />\n        </lib>\n        <lib type=\"SKF\" version=\"1.1\" dllname=\"ZXNhZmlucy5kbGw=\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SM3\" />\n        </lib>\n        <lib type=\"CSP\" version=\"1.0\" dllname=\"TWljcm9zb2Z0IEVuaGFuY2VkIENyeXB0b2dyYXBoaWMgUHJvdmlkZXIgdjEuMA==\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SHA1\" />\n        </lib>\n        <lib type=\"CSP\" version=\"1.0\" dllname=\"TWljcm9zb2Z0IFN0cm9uZyBDcnlwdG9ncmFwaGljIFByb3ZpZGVy\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SHA1\" />\n        </lib>\n        <lib type=\"CSP\" version=\"1.0\" dllname=\"TWljcm9zb2Z0IEJhc2UgQ3J5cHRvZ3JhcGhpYyBQcm92aWRlciB2MS4w\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SHA1\" />\n        </lib>\n        <lib type=\"SKF\" version=\"1.0\" dllname=\"R0FLRVlfU0tGLmRsbA==\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SM3\" />\n        </lib>\n        <lib type=\"SKF\" version=\"1.0\" dllname=\"L3Vzci9sb2NhbC9saWI2NC9saWJTS0ZfR0FfYXBpLnNv\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SM3\" />\n        </lib>\n        <lib type=\"SKF\" version=\"1.0\" dllname=\"b3B0L0dBU1MvbGliU0tGL2xpYlNLRl9HQV9hcGkuc28=\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SM3\" />\n        </lib>\n        <lib type=\"SKF\" version=\"1.0\" dllname=\"SklUR01LRVlfU0pLMTQyNC5kbGw=\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SM3\" />\n        </lib>\n        <lib type=\"CSP\" version=\"1.1\" dllname=\"ZVNhZmUgQ3J5cHRvZ3JhcGhpYyBTZXJ2aWNlIFByb3ZpZGVyIHYxLjA=\">\n            <algid val=\"SHA1\" sm2_hashalg=\"SHA1\" />\n        </lib>\n    </liblist>\n</authinfo>";
        pnxclient_1.JIT_GW_ExtInterface.Init(enablectiveX, enableNPPlugin);
        if (initParam) {
            this.initParam = initParam;
        }
        // this.initParam = initParam;
    }
    JitClient.prototype.getBrowserInfo = function () {
        var userAgent = navigator.userAgent.toLowerCase();
        if (userAgent.indexOf("chrome") < 0) {
            // 非 Chrome ： 使用 IE ActiveX 组件
            // let obj = document.createElement('object');
            // obj.setAttribute('id', 'JITDSignOcx')
            // obj.setAttribute('classid', 'clsid:B0EF56AD-D711-412D-BE74-A751595F3633');
            // document.body.append(obj);
            return BROWSER_MODE.IE;
        }
        var version = 0;
        userAgent.split(" ").map(function (ptn) {
            if (ptn.indexOf("chrome") > -1) {
                version = parseInt(ptn.split("/")[1]);
            }
        });
        if (version < 45) {
            // 老旧 Chrome ： 使用 x-vctk 组件
            // let embed = document.createElement('embed');
            // embed.setAttribute('width', '0')
            // embed.setAttribute('height', '0')
            // embed.setAttribute('id', 'JITDSignOcx')
            // embed.setAttribute('type', 'application/x-jit-sign-vctk-s-plugin-boc');
            // document.body.append(embed);
            return BROWSER_MODE.CHROME_OLD;
        }
        // 新版  Chrome ，使用 Chrome 插件
        return BROWSER_MODE.CHROME;
    };
    JitClient.prototype.getLoginParam = function (randNum, initParam) {
        var signSubject = ""; //document.getElementById("rootCADN").value;
        // 验证认证原文是否为空
        // VCTK初始化参数，数据可从网关系统：认证管理->Key类型管理中导出
        // 调用网关工具脚本中的detachSignStr方法进行签名，返回签名结果
        // 参数说明：initParam：vctk控件初始化参数，authContent：认证原文，signSubject：证书版本者主题
        var signResult = detachSignStr(initParam || this.initParam, randNum, signSubject);
        if (signResult === false) {
            return false;
        }
        return { original: randNum, signed_data: signResult, authMode: "cert" };
    };
    return JitClient;
}());
exports.JitClient = JitClient;
// 根据原文和证书产生认证数据包
// 参数说明：initParam：vctk控件初始化参数
// 参数说明：authContent：认证原文
// 参数说明：signSubject：证书版发者主题
function detachSignStr(initParam, authContent, signSubject) {
    // 验证认证原文不能为空
    if (authContent == "") {
        alert("认证原文不能为空!");
        return false;
    }
    try {
        pnxclient_1.JIT_GW_ExtInterface.GetVersion();
    }
    catch (e) {
        alert("未安装控件，请进行安装控件");
        return false;
    }
    pnxclient_1.JIT_GW_ExtInterface.ClearFilter();
    // 初始化vctk控件
    pnxclient_1.JIT_GW_ExtInterface.Initialize("", initParam);
    // 控制证书为一个时，不弹出证书选择框
    pnxclient_1.JIT_GW_ExtInterface.SetChooseSingleCert(1);
    // 生成签名信息 
    var sign_Result = pnxclient_1.JIT_GW_ExtInterface.P7SignString(authContent, true, true);
    if (pnxclient_1.JIT_GW_ExtInterface.GetLastError() != 0) {
        if (pnxclient_1.JIT_GW_ExtInterface.GetLastError() == 3758096386
            || pnxclient_1.JIT_GW_ExtInterface.GetLastError() == 2148532334) {
            alert("用户取消操作");
            return false;
        }
        else if (pnxclient_1.JIT_GW_ExtInterface.GetLastError() == -536870815
            || pnxclient_1.JIT_GW_ExtInterface.GetLastError() == 3758096481) {
            alert("没有找到有效的证书，如果使用的是KEY，请确认已经插入key");
            return false;
        }
        else {
            alert(pnxclient_1.JIT_GW_ExtInterface.GetLastErrorMessage());
            return false;
        }
    }
    // 返回签名结果
    return sign_Result;
}
