export default abstract class {
    /**
     * getSuffix 可返回 /route 后面字符串 说明：
     * 1. 可能会返回 null , 业务代码需要根据 null 进行判断， null 时，不做数据处理
     * 2. 当 root / route 不匹配时，直接返回 null
     * 3. 当 root / route 匹配时， 返回 route 后面的部分
     * 4. 使用时，需要注册路由为 like:true
     * 5. 默认 slash 参数 = true ，多舍去一个字符 通常为 /route[/]{xxx} 里面的 [/] 也舍去，如果不想舍去，第四个参数传 false
    */
    static getSuffix(evt: any, root: string, route: string, slash?: boolean): string | null;
    /**
     * 获取URL链接的参数 ?a=1&b=2
     * Page.getParam('a') // '1'
     * Page.getParam('b') // '2'
     * Page.getParam('c') // ''
    */
    static getParam(param: any): string;
    static genId: () => any;
    /**
     * 随机生成guid
     */
    static getGuid: () => string;
    /**
     * @deprecated
     * 不支持 HASH
    * 获取URL链接的Hash参数 #a=1&b=2
    * Page.getHashParam('a') // '1'
    * Page.getHashParam('b') // '2'
    * Page.getHashParam('c') // ''
   */
    static getHashParam(param: any): string;
    /**
     * 加载权限
    */
    static loadRole(roleApi?: string): void;
    /**
     * 判断是否有权限
    */
    static hasRole(role: string): boolean;
    static layoutV(layout: {
        l: any;
        h: any;
    }, compoment: any, state: any): any;
    /**
     * 动态变化的高度与宽度
     *
     * s -1440 (1280)
     * m 1440-1600
     * l 1600-1920
     * xl 1920+
    */
    static layout(layout: {
        s: any;
        m?: any;
        l?: any;
        xl?: any;
    }, compoment: any, state: any): any;
    static ipToInt(ip: string): number;
    static ipToArea(ip: string): string;
}
