"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _ = require("lodash");
var Ajax_1 = require("./Ajax");
var Validate_1 = require("./Validate");
var copyValue = function (val, def) {
    if (_.isArray(val)) {
        return _.concat([], val || def);
    }
    else if (_.isNumber(val)) {
        return val || def;
    }
    return _.assign({}, def, val);
};
var MULTIPLIER = Math.pow(2, 20);
var seenKeys = {};
var IPS = [];
function IpToInt(ip) {
    var ipNum = 0;
    if (!Validate_1.default.isIp(ip)) {
        return ipNum;
    }
    return ip.split('.').reduce(function (ipInt, octet) { return (ipInt << 8) + parseInt(octet, 10); }, 0) >>> 0;
}
var default_1 = /** @class */ (function () {
    function default_1() {
    }
    /**
     * getSuffix 可返回 /route 后面字符串 说明：
     * 1. 可能会返回 null , 业务代码需要根据 null 进行判断， null 时，不做数据处理
     * 2. 当 root / route 不匹配时，直接返回 null
     * 3. 当 root / route 匹配时， 返回 route 后面的部分
     * 4. 使用时，需要注册路由为 like:true
     * 5. 默认 slash 参数 = true ，多舍去一个字符 通常为 /route[/]{xxx} 里面的 [/] 也舍去，如果不想舍去，第四个参数传 false
    */
    default_1.getSuffix = function (evt, root, route, slash) {
        if (slash === void 0) { slash = true; }
        if (window.location.pathname != root) {
            return null;
        }
        var pathname = window.location.hash;
        if (evt && evt.location) {
            pathname = evt.location.pathname;
        }
        else if (pathname && pathname.length) {
            pathname = pathname.substring(1);
        }
        if (!_.startsWith(pathname, route)) {
            return null;
        }
        return pathname.substring(route.length + (slash ? 1 : 0));
    };
    /**
     * 获取URL链接的参数 ?a=1&b=2
     * Page.getParam('a') // '1'
     * Page.getParam('b') // '2'
     * Page.getParam('c') // ''
    */
    default_1.getParam = function (param) {
        var reg = window.location.search.match(new RegExp("[\?\&]" + param + "=([^\&]*)(\&?)", "i"));
        if (reg != null) {
            return decodeURI(reg[1]);
        }
        return '';
    };
    /**
     * @deprecated
     * 不支持 HASH
    * 获取URL链接的Hash参数 #a=1&b=2
    * Page.getHashParam('a') // '1'
    * Page.getHashParam('b') // '2'
    * Page.getHashParam('c') // ''
   */
    default_1.getHashParam = function (param) {
        var reg = window.location.hash.match(new RegExp("[\?\&]" + param + "=([^\&]*)(\&?)", "i"));
        if (reg != null) {
            return decodeURI(reg[1]);
        }
        return '';
    };
    /**
     * 加载权限
    */
    default_1.loadRole = function (roleApi) {
        if (roleApi === void 0) { roleApi = '/api-common/role/rules'; }
        window['_VAP_ROLE'] = new Set();
        Ajax_1.default.SESION(roleApi);
        Ajax_1.default.GET(roleApi, function (json) {
            json.data.map(function (item) {
                window['_VAP_ROLE'].add(item.path);
            });
        });
    };
    /**
     * 判断是否有权限
    */
    default_1.hasRole = function (role) {
        return window['_VAP_ROLE'].has(role);
    };
    default_1.layoutV = function (layout, compoment, state) {
        var LAYOUT = {};
        LAYOUT.l = copyValue(layout.l, {});
        LAYOUT.h = copyValue(layout.h, layout.l);
        var height = window.innerHeight;
        var size = 'l';
        if (height >= 768) {
            size = 'h';
        }
        window.addEventListener('resize', function () {
            var _a;
            height = window.innerHeight;
            size = 'l';
            if (height >= 768) {
                size = 'h';
            }
            if (compoment) {
                compoment.setState((_a = {},
                    _a[state] = LAYOUT[size],
                    _a));
            }
        });
        return LAYOUT[size];
    };
    /**
     * 动态变化的高度与宽度
     *
     * s -1440 (1280)
     * m 1440-1600
     * l 1600-1920
     * xl 1920+
    */
    default_1.layout = function (layout, compoment, state) {
        var LAYOUT = {};
        LAYOUT.s = copyValue(layout.s, {});
        LAYOUT.m = copyValue(layout.m, layout.s);
        LAYOUT.l = copyValue(layout.l, layout.m);
        LAYOUT.xl = copyValue(layout.xl, layout.l);
        var width = window.innerWidth;
        var size = 's';
        if (width >= 1920) {
            size = 'xl';
        }
        else if (width >= 1600) {
            size = 'l';
        }
        else if (width >= 1440) {
            size = 'm';
        }
        window.addEventListener('resize', function () {
            var _a;
            width = window.innerWidth;
            size = 's';
            if (width >= 1920) {
                size = 'xl';
            }
            else if (width >= 1600) {
                size = 'l';
            }
            else if (width >= 1440) {
                size = 'm';
            }
            if (compoment) {
                compoment.setState((_a = {},
                    _a[state] = LAYOUT[size],
                    _a));
            }
        });
        return LAYOUT[size];
    };
    default_1.ipToInt = function (ip) {
        var ipNum = 0;
        if (!Validate_1.default.isIp(ip)) {
            return ipNum;
        }
        return ip.split('.').reduce(function (ipInt, octet) { return (ipInt << 8) + parseInt(octet, 10); }, 0) >>> 0;
    };
    ;
    default_1.ipToArea = function (ip) {
        var areaName = '未知';
        if (IPS.length <= 0) {
            var resp = Ajax_1.default.GETASYNC('/api-common/organization/ip/byArea');
            IPS = _.isArray(resp.data) ? resp.data : [];
        }
        var ipNum = IpToInt(ip);
        var ipMatch = _.filter(IPS, function (ip) { return ip.startIpNum <= ipNum && ip.endIpNum >= ipNum; });
        if (ipMatch.length == 1) {
            areaName = ipMatch[0].areaName;
        }
        return areaName;
    };
    default_1.genId = function () {
        var key = void 0;
        while (key === undefined || seenKeys.hasOwnProperty(key) || !isNaN(+key)) {
            key = Math.floor(Math.random() * MULTIPLIER).toString(32);
        }
        seenKeys[key] = true;
        return key;
    };
    /**
     * 随机生成guid
     */
    default_1.getGuid = function () {
        return Math.random().toString(36).substring(2);
    };
    return default_1;
}());
exports.default = default_1;
