"use strict";
/**
 * 正则表达式
 */
Object.defineProperty(exports, "__esModule", { value: true });
var default_1 = /** @class */ (function () {
    function default_1() {
    }
    /**
     * 验证单个IP不带端口号
     */
    default_1.singleIp = /^((25[0-5]|2[0-4]\d|((1\d{2})|([1-9]?\d)))\.){3}(25[0-5]|2[0-4]\d|((1\d{2})|([1-9]?\d)))$/;
    /**
     * 验证单个IP带端口号
     */
    default_1.singleIpAndPort = /^((25[0-5]|2[0-4]\d|((1\d{2})|([1-9]?\d)))\.){3}(25[0-5]|2[0-4]\d|((1\d{2})|([1-9]?\d))):([0-9]|[1-9]\d{1,3}|[1-5]\d{4}|6[0-5]{2}[0-3][0-5])$/;
    /**
     * 验证多个IP
     * ip之间以,隔开
     */
    default_1.mutiIp = /^((25[0-5]|2[0-4]\d|((1\d{2})|([1-9]?\d)))\.){3}(25[0-5]|2[0-4]\d|((1\d{2})|([1-9]?\d)))(,((25[0-5]|2[0-4]\d|((1\d{2})|([1-9]?\d)))\.){3}(25[0-5]|2[0-4]\d|((1\d{2})|([1-9]?\d))))*$/;
    /**
     * 验证单个IPv6地址
     */
    default_1.singleIpv6 = /^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))$/;
    /**
     * 验证MAC地址
     */
    default_1.macAddr = /^((([a-f0-9]{2}:){5})|(([a-f0-9]{2}-){5}))[a-f0-9]{2}|((([A-F0-9]{2}:){5})|(([A-F0-9]{2}-){5}))[A-F0-9]{2}$/;
    /**
     * 验证身份证号码
     */
    default_1.idCard = /^[1-9]\d{5}(18|19|([23]\d))\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\d{3}[0-9Xx]$/;
    /**
     * 验证网址
     * 网址需要以http|ftp|https开头
     */
    default_1.webSite = /^((http|ftp|https):\/\/)(([a-zA-Z0-9\._-]+\.[a-zA-Z]{2,6})|([0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}))(:([0-9]|[1-9]\d{1,3}|[1-5]\d{4}|6[0-5]{2}[0-3][0-5]))*(\/[a-zA-Z0-9\&#%_\.\/-~-]*)*$/;
    /**
     * 验证是否在经度范围内
     * -180~180
     */
    default_1.lng = /^-?(?:(?:180(?:\.0{1,8})?)|(?:(?:(?:1[0-7]\d)|(?:[1-9]?\d))(?:\.\d{1,8})?))$/;
    /**
     *  判断是否在纬度范围内
     * -90~90
     */
    default_1.lat = /^-?(?:90(?:\.0{1,8})?|(?:[1-8]?\d(?:\.\d{1,8})?))$/;
    /**
     * 验证是否为中文、英文字母、数字和_
     */
    default_1.normalWords = /^[\u4e00-\u9fa5_a-zA-Z0-9]+$/;
    /**
     * 验证是否为英文字母、数字和_
     */
    default_1.enNumWords = /^[_a-zA-Z0-9]+$/;
    /**
     * 验证端口格式
     */
    default_1.port = /^([0-9]|[1-9]\d{1,3}|[1-5]\d{4}|6[0-5]{2}[0-3][0-5])$/;
    /**
     * 手机号码
    */
    default_1.phone = /^((13[0-9])|(14[1,4-9])|(15[0-3,5-9])|(16[0,2,5-9])|(17[0-9])|(18[0-9])|(19[0-3,5-9]))\d{8}$/;
    /**
     * 固定电话号码
     */
    default_1.mobile = /^(0[0-9]{2,3}-)?([2-9][0-9]{6,7})+(-[0-9]{1,4})?$/;
    /**
     * 邮箱
    */
    default_1.email = /^[A-Za-z0-9\u4e00-\u9fa5_]+@[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)+$/;
    /**
     * 邮箱
    */
    default_1.illegalChar = /[\'"#$?：!！？%￥&^*]/im;
    return default_1;
}());
exports.default = default_1;
