"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var _ = require("lodash");
var moment = require("moment");
var Format_1 = require("./Format");
var antd_1 = require("antd");
var PageUtil_1 = require("./PageUtil");
var _DictRender_1 = require("./_DictRender");
var Copy_1 = require("../_common/Copy");
var Paragraph = antd_1.Typography.Paragraph;
var TEXT = window.VAP_GLOBAL.TIPS;
var Renders = /** @class */ (function () {
    function Renders() {
    }
    /**
     * 字符串截取 Render
     * @param len 截取长度，默认为 20
     * @param hasDot 是否有3个省略号 默认为 true
     * @param className className
    */
    Renders.strRender = function (len, hasDot, className, onlyText) {
        if (len === void 0) { len = 20; }
        if (hasDot === void 0) { hasDot = true; }
        if (className === void 0) { className = undefined; }
        if (onlyText === void 0) { onlyText = false; }
        var fn = function (str) {
            if (str === null || str === undefined) {
                return '';
            }
            // MAKE BUG FOR STRING : 'null' 
            str = str == 'null' ? '' : str;
            return onlyText ? Format_1.default.formatString(str, len, hasDot) : React.createElement("span", { className: className, title: str }, Format_1.default.formatString(str, len, hasDot));
        };
        return fn;
    };
    /**
 * 字符串截取支持copy strCopyRender
 * @param len 截取长度，默认为 20
 * @param hasDot 是否有3个省略号 默认为 true
 * @param className className
*/
    Renders.strCopyRender = function (len, hasDot, className, onlyText) {
        if (len === void 0) { len = 20; }
        if (hasDot === void 0) { hasDot = true; }
        if (className === void 0) { className = undefined; }
        if (onlyText === void 0) { onlyText = false; }
        var fn = function (str) {
            if (str === null || str === undefined) {
                return '';
            }
            // MAKE BUG FOR STRING : 'null' 
            str = str == 'null' ? '' : str;
            return React.createElement("span", { className: className, title: str },
                Format_1.default.formatString(str, len, hasDot),
                " ",
                React.createElement(Copy_1.default, { value: str }));
        };
        return fn;
    };
    /**
     * 字符串根据宽度截取长度
     * @param config 参考antd Paragraph组件
     * @returns
     */
    Renders.autoStrRender = function (config) {
        var fn = function (str) {
            return React.createElement("div", { style: { width: '100%', display: 'inline-block', verticalAlign: 'top' }, title: str },
                React.createElement(Paragraph, __assign({ ellipsis: true }, config, { style: __assign({ margin: 0 }, (config && config.style)) }),
                    " ",
                    str,
                    " "));
        };
        return fn;
    };
    /**
    * 字符串转tag Render
    * @param split 根据split参数分割字符串
    * @param config 配置扩展功能
   */
    Renders.strToTagsRender = function (config) {
        //config中默认配置
        var split = ',';
        var len = 3;
        var strRender = Renders.strRender();
        var format = function (str) { return str; };
        var className = '';
        //配置赋值
        if (config) {
            if (config.split)
                split = config.split;
            if (config.len)
                len = config.len;
            if (config.strRenderLen)
                strRender = Renders.strRender(config.strRenderLen);
            if (config.format)
                format = config.format;
            if (_.isString(config.className))
                className = config.className;
        }
        var fn = function (str) {
            if (!_.isString(str))
                return;
            //根据split参数进行分割字符串 保留len长度
            var strs = _.filter(str.split(split), function (o) { return !!o; });
            var sliceStrs = [];
            if (strs.length > len) {
                sliceStrs = strs.slice(0, len);
            }
            else {
                sliceStrs = strs;
            }
            var expand = function () {
                return React.createElement("ul", { style: { padding: 0, margin: 0, listStyle: 'none', lineHeight: '32px', maxHeight: 300, overflow: 'auto' } }, strs.map(function (item, index) {
                    if (config && config.className && !_.isString(config.className))
                        className = config.className(item);
                    var value = strRender ? strRender(format(item)) : format(item);
                    return React.createElement("li", null,
                        React.createElement("span", { className: 'vapfont' },
                            index + 1,
                            ". "),
                        React.createElement(antd_1.Tag, { className: className }, value));
                }));
            };
            return sliceStrs.map(function (item, index) {
                var value = strRender ? strRender(format(item)) : format(item);
                if (config && config.className && !_.isString(config.className))
                    className = config.className(item);
                if (index == sliceStrs.length - 1 && strs.length > len) {
                    return React.createElement(React.Fragment, null,
                        React.createElement(antd_1.Tag, { className: className }, value),
                        React.createElement(antd_1.Popover, { content: expand() },
                            React.createElement(antd_1.Tag, null, "...")));
                }
                return React.createElement(antd_1.Tag, { className: className }, value);
            });
        };
        return fn;
    };
    /**
     * 长字符串截取 Render， 可copy
     * @param len 截取长度，默认为 20
     * @param hasDot 是否有3个省略号 默认为 true
     * @param className className
     *
     * @returns 不能为text
    */
    Renders.longstrRender = function (len, hasDot) {
        if (len === void 0) { len = 20; }
        if (hasDot === void 0) { hasDot = true; }
        var fn = function (str) {
            return React.createElement(antd_1.Tooltip, { title: str }, Format_1.default.formatString(str, len, hasDot));
        };
        return fn;
    };
    // function asyncListRender(){
    // }
    /**
     * 列表 Render 构造器
     * @param arr 默认为一个空数组
     * @param value 数据对应取值的字段 默认为 'id'
     * @param name 数据对应显示的字段 默认为 'name'
     * @param def 数据没有找到时的字段
    */
    Renders.listRender = function (arr, value, name, def, onlyText) {
        if (arr === void 0) { arr = []; }
        if (value === void 0) { value = 'id'; }
        if (name === void 0) { name = 'name'; }
        if (def === void 0) { def = TEXT.RENDER_TEXT; }
        if (onlyText === void 0) { onlyText = true; }
        var VALUES = {};
        var _list = arr;
        _list.map(function (item) {
            VALUES[item[value]] = item[name];
        });
        var fn = function (val) {
            var key = val + '';
            var text = def ? def : key;
            if (_.has(VALUES, key)) {
                text = VALUES[key];
            }
            return onlyText ? text : React.createElement("span", null, text);
        };
        fn.update = function (list) {
            VALUES = {};
            _list = list;
            list.map(function (item) {
                VALUES[item[value]] = item[name];
            });
        };
        fn.options = function (nameField, valueField) {
            if (nameField === void 0) { nameField = 'name'; }
            if (valueField === void 0) { valueField = 'value'; }
            return (_list || []).map(function (item) {
                var _a;
                return (_a = {},
                    _a[nameField] = item[name],
                    _a[valueField] = item[value],
                    _a);
            });
        };
        return fn;
    };
    /**
     * 状态 Render 构造器
     * @param statusMap 一个StatusMap 默认为  { success: { name: '正常', value: 0 }, error: { name: '异常', value: 1 } }
     * @param def 数据没有找到时的显示名称 默认为 '未知'
    */
    Renders.statusRender = function (statusMap, def, onlyText) {
        if (statusMap === void 0) { statusMap = { success: { name: '正常', value: 0 }, error: { name: '异常', value: 1 } }; }
        if (def === void 0) { def = '未知'; }
        if (onlyText === void 0) { onlyText = false; }
        var STYLES = {};
        var VALUES = {};
        var _statusMap = statusMap;
        _.keys(statusMap).map(function (style) {
            var key = statusMap[style].value + '';
            STYLES[key] = style;
            VALUES[key] = statusMap[style].name;
        });
        var fn = function (val) {
            var key = val + '';
            var style = 'default';
            var text = def === false ? val : def;
            if (_.has(VALUES, key)) {
                text = VALUES[key];
            }
            if (_.has(STYLES, key)) {
                style = STYLES[key];
            }
            return onlyText ? text : React.createElement(antd_1.Badge, { status: style, text: text });
        };
        fn.update = function (statusMap) {
            _statusMap = statusMap;
            _.keys(statusMap).map(function (style) {
                var key = statusMap[style].value + '';
                STYLES[key] = style;
                VALUES[key] = statusMap[style].name;
            });
        };
        fn.options = function (nameField, valueField) {
            if (nameField === void 0) { nameField = 'name'; }
            if (valueField === void 0) { valueField = 'value'; }
            return _.keys(_statusMap).map(function (style) {
                var _a;
                return (_a = {},
                    _a[nameField] = fn(_statusMap[style].value),
                    _a[valueField] = _statusMap[style].value,
                    _a);
            });
            // return (_list || []).map(item => ({
            //     [nameField]: item[name],
            //     [valueField]: item[value],
            // }))
        };
        return fn;
    };
    /**
     * Monment 时间 Render 构造器,可以在近一段时间内显示 （x小时前）之类的字串
     * @param time 是否显示时分秒，默认为 true 即 `YYYY-MM-DD HH:mm:ss`, 设置为 `false` 则显示为'YYYY-MM-DD'
     * @param nearly 最近 {x} 天 时，转换为 moment 方式显示，比如 5秒前，15小时前，2天前等等。 默认为 3
     *
    */
    Renders.momentRender = function (time, nearly, onlyText) {
        if (time === void 0) { time = true; }
        if (nearly === void 0) { nearly = 0; }
        if (onlyText === void 0) { onlyText = true; }
        var now = moment();
        var from = now.unix();
        var fn = function (val) {
            if (val == null || val == '') {
                return '';
            }
            // let time = format ? moment(val, format) : moment(new Date(val));
            var time = moment(val);
            if (!time.isValid()) {
                return val;
            }
            var to = time.unix();
            var diff = from - to;
            var txt = '';
            if (diff >= 0 && diff < 86400 * nearly) {
                txt = time.fromNow();
            }
            else if (time) {
                txt = time.format('YYYY-MM-DD HH:mm:ss');
            }
            else {
                txt = time.format('YYYY-MM-DD');
            }
            return onlyText ? txt : React.createElement("span", { title: val }, txt);
        };
        fn.update = function () {
            now = moment();
            from = now.unix();
        };
        return fn;
    };
    /**
     *
     * 时间 Render 构造器
     * @param 时间
    */
    Renders.dateRender = function (format, onlyText) {
        if (format === void 0) { format = 'YYYY-MM-DD HH:mm:ss'; }
        if (onlyText === void 0) { onlyText = true; }
        var fn = function (val) {
            if (val == null || val == '') {
                return '';
            }
            var mnt = moment(val);
            if (!mnt.isValid()) {
                return val;
            }
            return onlyText ? mnt.format(format) : React.createElement("span", { title: val }, mnt.format(format));
        };
        return fn;
    };
    /**
     *
     * 容量 Render 构造器
     * @param byte number 大小
    */
    Renders.sizeRender = function (onlyText) {
        if (onlyText === void 0) { onlyText = true; }
        var fn = function (val) {
            return onlyText ? Format_1.default.formatSize(val) : React.createElement("span", { className: "vapfont", title: Format_1.default.formatSize(val) }, Format_1.default.formatSize(val));
        };
        return fn;
    };
    /**
     * 返回一个 htmlRender，用于显示自定义的html,会用div包住
     * @param className 包住自定义html的 className 默认为空
    */
    Renders.htmlRender = function (className) {
        if (className === void 0) { className = ''; }
        return function (val) {
            return React.createElement("div", { className: className, dangerouslySetInnerHTML: { __html: val } });
        };
    };
    /**
     * 角色权限Render
     * */
    Renders.roleRender = function (role, render) {
        return PageUtil_1.default.hasRole(role) ? render : [];
    };
    /**
     * 字典表Render
     * */
    Renders.dictRender = _DictRender_1.dictRender;
    return Renders;
}());
exports.default = Renders;
